@@ -61,6 +61,8 @@ def check_output(operation):
 
 class NetmikoSwitch(devices.GenericSwitchDevice):
 
+    NETMIKO_DEVICE_TYPE = None
+
     ADD_NETWORK = None
 
     DELETE_NETWORK = None
@@ -88,9 +90,12 @@ class NetmikoSwitch(devices.GenericSwitchDevice):
 
     def __init__(self, device_cfg):
         super(NetmikoSwitch, self).__init__(device_cfg)
-        device_type = self.config.get('device_type', '')
-        # use part that is after 'netmiko_'
-        device_type = device_type.partition('netmiko_')[2]
+        if self.NETMIKO_DEVICE_TYPE:
+            device_type = self.NETMIKO_DEVICE_TYPE
+        else:
+            device_type = self.config.get('device_type', '')
+            # use part that is after 'netmiko_'
+            device_type = device_type.partition('netmiko_')[2]
         if device_type not in netmiko.platforms:
             raise exc.GenericSwitchNetmikoNotSupported(
                 device_type=device_type)
@@ -195,6 +200,10 @@ class NetmikoSwitch(devices.GenericSwitchDevice):
 
     @check_output('add network')
     def add_network(self, segmentation_id, network_id):
+        if not self._do_vlan_management():
+            LOG.info(f"Skipping add network for {segmentation_id}")
+            return ""
+
         # NOTE(zhenguo): Remove dashes from uuid as on most devices 32 chars
         # is the max length of vlan name.
         network_id = uuid.UUID(network_id).hex
@@ -213,6 +222,10 @@ class NetmikoSwitch(devices.GenericSwitchDevice):
 
     @check_output('delete network')
     def del_network(self, segmentation_id, network_id):
+        if not self._do_vlan_management():
+            LOG.info(f"Skipping delete network for {segmentation_id}")
+            return ""
+
         # NOTE(zhenguo): Remove dashes from uuid as on most devices 32 chars
         # is the max length of vlan name.
         network_id = uuid.UUID(network_id).hex
